@@ -552,12 +552,21 @@ def get_version_id_for(servicecatalog, product_id, version_name):
 def get_portfolio_for(servicecatalog, portfolio_name):
     result = None
 
+    response = servicecatalog.list_accepted_portfolio_shares(PortfolioShareType="AWS_ORGANIZATIONS")
+    assert response.get('NextPageToken') is None, "Pagination not supported"
+    for portfolio_detail in response.get('PortfolioDetails'):
+        if portfolio_detail.get('DisplayName') == portfolio_name:
+            result = portfolio_detail
+            break
+    logger.info(f"Did not find {portfolio_name} in AWS_ORGANIZATIONS PortfolioShareType")
+
     response = servicecatalog.list_accepted_portfolio_shares()
     assert response.get('NextPageToken') is None, "Pagination not supported"
     for portfolio_detail in response.get('PortfolioDetails'):
         if portfolio_detail.get('DisplayName') == portfolio_name:
             result = portfolio_detail
             break
+    logger.info(f"Did not find {portfolio_name} in IMPORTED PortfolioShareType")
 
     if result is None:
         response = servicecatalog.list_portfolios_single_page()
@@ -565,6 +574,7 @@ def get_portfolio_for(servicecatalog, portfolio_name):
             if portfolio_detail.get('DisplayName') == portfolio_name:
                 result = portfolio_detail
                 break
+    logger.info(f"Did not find {portfolio_name} in local portfolio list")
 
     assert result is not None, "Could not find portfolio"
     return result
