@@ -4,11 +4,9 @@ from pathlib import Path
 
 import cfn_tools
 import requests
-from colorclass import Color
 import terminaltables
 
 import shutil
-import json
 from threading import Thread
 
 import pkg_resources
@@ -56,7 +54,7 @@ def generate_shares(f):
     logger.info('Starting to generate shares for: {}'.format(f.name))
     tasks_to_run = []
     puppet_account_id = config.get_puppet_account_id()
-    manifest = manifest_utils.load(f)
+    manifest = manifest_utils.load(f, puppet_account_id)
     accounts_by_id = {}
     for account in manifest.get('accounts'):
         accounts_by_id[account.get('account_id')] = account
@@ -129,7 +127,7 @@ def generate_shares(f):
 
 def reset_provisioned_product_owner(f):
     puppet_account_id = config.get_puppet_account_id()
-    manifest = manifest_utils.load(f)
+    manifest = manifest_utils.load(f, puppet_account_id)
 
     task_defs = manifest_utils_for_launches.generate_launch_tasks(
         manifest, puppet_account_id, False, False
@@ -150,9 +148,10 @@ def reset_provisioned_product_owner(f):
     runner.run_tasks(tasks_to_run, 10)
 
 
-def generate_tasks(f, single_account=None, is_dry_run=False):
+def generate_tasks(f, single_account=None, is_dry_run=False, execution_mode='hub'):
+    logger.error(f"core.generate_tasks execution_mode is {execution_mode}")
     puppet_account_id = config.get_puppet_account_id()
-    manifest = manifest_utils.load(f)
+    manifest = manifest_utils.load(f, puppet_account_id)
 
     should_use_sns = config.get_should_use_sns(os.environ.get("AWS_DEFAULT_REGION"))
     should_use_product_plans = config.get_should_use_product_plans(os.environ.get("AWS_DEFAULT_REGION"))
@@ -165,6 +164,7 @@ def generate_tasks(f, single_account=None, is_dry_run=False):
         include_expanded_from=False,
         single_account=single_account,
         is_dry_run=is_dry_run,
+        execution_mode=execution_mode,
     )
     logger.info("Finished generating provisioning tasks")
 
@@ -186,9 +186,10 @@ def generate_tasks(f, single_account=None, is_dry_run=False):
     return tasks_to_run
 
 
-def deploy(f, single_account, num_workers=10, is_dry_run=False, is_list_launches=False):
-    tasks_to_run = generate_tasks(f, single_account, is_dry_run)
-    runner.run_tasks(tasks_to_run, num_workers, is_dry_run, is_list_launches)
+def deploy(f, single_account, num_workers=10, is_dry_run=False, is_list_launches=False, execution_mode='hub'):
+    logger.error(f"core.deploy execution_mode is {execution_mode}")
+    tasks_to_run = generate_tasks(f, single_account, is_dry_run, execution_mode)
+    runner.run_tasks(tasks_to_run, num_workers, is_dry_run, is_list_launches, execution_mode)
 
 
 def graph(f):
@@ -473,7 +474,8 @@ def seed(complexity, p):
 
 def expand(f):
     click.echo('Expanding')
-    manifest = manifest_utils.load(f)
+    puppet_account_id = config.get_puppet_account_id()
+    manifest = manifest_utils.load(f, puppet_account_id)
     org_iam_role_arn = config.get_org_iam_role_arn()
     if org_iam_role_arn is None:
         click.echo('No org role set - not expanding')
